import React from "react";
import ContentType from "./ContentType";
import ActionType from "./ActionType";
import { GenerateGUID } from "../Utils";

var DefaultMessage = {
  CurrentID: undefined,
  RoomID: undefined,
  MessageContent: {
    ActionType: undefined,
    ContentType: undefined,
    ContentValue: undefined
  }
};

function GetDefaultObject() {
  return Object.assign({}, DefaultMessage);
}

var MessageBuilder = {
  AppConnected: function AppConnected(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.APP_CONNECTED;
    returnMessage.MessageContent.ContentType = ContentType.TEXT_PLAIN;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  AppDisconected: function AppDisconected(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.APP_DISCONNECTED;
    returnMessage.MessageContent.ContentType = ContentType.APPLICATION_JSON;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  HostConnected: function HostConnected(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.HOST_CONNECTED;
    returnMessage.MessageContent.ContentType = ContentType.APPLICATION_JSON;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  HostDisconnected: function HostDisconnected(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.HOST_DISCONNECTED;
    returnMessage.MessageContent.ContentType = ContentType.APPLICATION_JSON;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  AnexoPedidoMedico: function AnexoPedidoMedico(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.PEDIDO_MEDICO_ANEXO;
    returnMessage.MessageContent.ContentType = ContentType.APPLICATION_BASE64;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  Texto: function Texto(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.ENVIAR_TEXTO_LAUDO;
    returnMessage.MessageContent.ContentType = ContentType.TEXT_PLAIN;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  Audio: function Audio(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.DITADO_AUDIO;
    returnMessage.MessageContent.ContentType = ContentType.APPLICATION_BASE64;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  StateChanged: function StateChanged(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.STATE_CHANGED;
    returnMessage.MessageContent.ContentType = ContentType.APPLICATION_JSON;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  Laudar: function Laudar(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.ATALHO_ACAO_LAUDAR;
    returnMessage.MessageContent.ContentType = ContentType.APPLICATION_JSON;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  Revisar: function Revisar(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.ATALHO_ACAO_REVISAR;
    returnMessage.MessageContent.ContentType = ContentType.APPLICATION_JSON;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  LaudarRevisar: function LaudarRevisar(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.ATALHO_ACAO_LAUDAR_REVISAR;
    returnMessage.MessageContent.ContentType = ContentType.APPLICATION_JSON;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  ReconhecimentoSTT: function ReconhecimentoSTT(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.RECONHECIMENTO_VOZ_STT;
    returnMessage.MessageContent.ContentType = ContentType.TEXT_PLAIN;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  },
  ComandoAssistente: function ComandoAssistente(content) {
    var returnMessage = GetDefaultObject();
    returnMessage.CurrentID = GenerateGUID();
    returnMessage.RoomID = "";
    returnMessage.MessageContent.ActionType = ActionType.COMANDO_ASSISTENTE;
    returnMessage.MessageContent.ContentType = ContentType.APPLICATION_JSON;
    returnMessage.MessageContent.ContentValue = content;
    return returnMessage;
  }
};

export { MessageBuilder, ContentType, ActionType };