"use strict";

exports.__esModule = true;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; /* global WebSocket */
/* eslint no-unused-vars: "off" */


var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _propTypes = require("prop-types");

var _propTypes2 = _interopRequireDefault(_propTypes);

var _Utils = require("../Utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function NormalizeDataToBase64(data) {
  var message = Object.assign({}, data);

  if ((typeof message === "undefined" ? "undefined" : _typeof(message)) === "object") message = JSON.stringify(message);

  if (!_Utils.Base64.isBase64(message)) message = _Utils.Base64.btoa(message);

  return message;
}

var _websocket;
var WebSocketClient = {
  send: function send(data) {
    if (!_websocket) return;

    _websocket.send(data);
  },
  sendAsBase64: function sendAsBase64(data) {
    if (!_websocket) return;
    var message = NormalizeDataToBase64(data);

    _websocket.send(message);
  },
  close: function close() {
    if (!_websocket) return;

    _websocket.close();
    _websocket = undefined;
  },
  isConnected: function isConnected() {
    if (!_websocket) return false;

    return _websocket.readyState === 1;
  },
  getState: function getState() {
    if (!_websocket) return 3;

    return _websocket.readyState;
  },
  connect: function connect(url, openCallback, onErrorCallback, onMessageCallback, onCloseCallback) {
    _websocket = new WebSocket(url);
    _websocket.onopen = function (event) {
      if (openCallback) openCallback(event);
    };
    _websocket.onmessage = function (event) {
      if (onMessageCallback) onMessageCallback(event);
    };
    _websocket.onerror = function (event) {
      if (onErrorCallback) onErrorCallback(event);
    };
    _websocket.onclose = function (event) {
      if (onCloseCallback) onCloseCallback(event);
    };
  }
};

exports.default = WebSocketClient;
//export default WebSocketClient;

module.exports = exports["default"];